@@ -12,9 +12,9 @@ OC.L10N.register(
     "Day" : "Tago",
     "Week" : "Semajno",
     "Month" : "Monato",
+    "Delete" : "Forigi",
     "Copy private link" : "Kopii privatan ligilon",
     "Download" : "Elŝuti",
-    "Delete" : "Forigi",
     "Calendar link copied to clipboard." : "Kalendara ligilo kopiita al tondujo",
     "Calendar link could not be copied to clipboard." : "Kalendara ligilo ne eblis esti kopiita al tondujo",
     "Share link" : "Kunhavigi ligilon",
@@ -23,49 +23,47 @@ OC.L10N.register(
     "No users or groups" : "Neniu uzanto aŭ grupo",
     "can edit" : "povas redakti",
     "New calendar" : "Nova kalendaro",
-    "Untitled event" : "Sentitola okazaĵo",
     "Filename" : "Dosiernomo",
     "Cancel" : "Nuligi",
     "Automatic" : "Aŭtomata",
     "Actions" : "Agoj",
     "Show week numbers" : "Montri numerojn de semajno",
     "Settings & import" : "Agordoj kaj enporto",
+    "Location" : "Loko",
+    "Description" : "Priskribo",
+    "Monday" : "lundo",
+    "Save" : "Konservi",
+    "Update" : "Ĝisdatigi",
     "Email" : "Retpoŝto",
     "Busy" : "Okupita",
     "Unknown" : "Nekonata",
     "All day" : "Tuttage",
+    "Repeat" : "Ripeti",
     "never" : "neniam",
     "after" : "post",
-    "Repeat" : "Ripeti",
-    "Monday" : "lundo",
-    "Summary" : "Resumo",
     "More" : "Pli",
-    "Save" : "Konservi",
-    "Update" : "Ĝisdatigi",
+    "Global" : "Monda",
     "Personal" : "Persona",
     "[Today]" : "[Hodiaŭ]",
     "[Tomorrow]" : "[Morgaŭ]",
     "[Yesterday]" : "[Hieraŭ]",
     "Details" : "Detaloj",
     "Attendees" : "Ĉeestontoj",
-    "Reminders" : "Memorigoj",
     "Close" : "Fermi",
     "Anniversary" : "Datreveno",
     "Week {number} of {year}" : "Semajno {number} en {year}",
     "Daily" : "Ĉiutage",
     "Weekly" : "Ĉiusemajne",
+    "Untitled event" : "Sentitola okazaĵo",
     "When shared show full event" : "Kiam kunhavigita, montri plenajn detalojn",
     "When shared show only busy" : "Kiam kunhavigita, montri nur kiel okupita",
     "When shared hide this event" : "Kiam kunhavigita, kaŝi tiun okazaĵon",
-    "Location" : "Loko",
-    "Description" : "Priskribo",
     "Status" : "Stato",
     "Confirmed" : "Konfirmita",
     "Tentative" : "Nekonfirmita",
     "Canceled" : "Nuligita",
     "Categories" : "Kategorioj",
     "Add this as a new category" : "Aldoni tion kiel novan kategorion",
-    "Mail" : "Retpoŝtilo",
-    "Global" : "Monda"
+    "Mail" : "Retpoŝtilo"
 },
 "nplurals=2; plural=(n != 1);");
