@@ -24,6 +24,7 @@ OC.L10N.register(
     "Week" : "Tuần",
     "Month" : "Tháng",
     "List" : "Danh sách",
+    "Delete" : "Xóa",
     "Untitled calendar" : "Lịch không tiêu đề",
     "Edit name" : "Sửa đổi tên",
     "Saving name …" : "Đang lưu tên  …",
@@ -32,7 +33,6 @@ OC.L10N.register(
     "Copy private link" : "Sao chép liên kết riêng tư",
     "Download" : "Tải về",
     "Unshare from me" : "Gỡ chia sẻ khỏi tôi",
-    "Delete" : "Xóa",
     "An error occurred, unable to change visibility of the calendar." : "Một lỗi đã xảy ra, không thể thay đổi tính hiển thị của lịch.",
     "An error occurred, unable to delete the calendar." : "Một lỗi đã xảy ra, không thể xóa lịch.",
     "Calendar link copied to clipboard." : "Liên kết của lịch đã được sao chép vào bảng tạm.",
@@ -77,7 +77,6 @@ OC.L10N.register(
     "Creating subscription …" : "Đang tạo đăng kí theo dõi mới  …",
     "An error occurred, unable to create the calendar." : "Một lỗi đã xảy ra, không thẻ tạo lịch.",
     "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Vui lòng nhập vào một liên kết khả dụng ( bắt đầu với http://, https://, webcal://, hoặc webcals://)",
-    "Untitled event" : "Sự kiện không tiêu đề",
     "Could not update calendar order." : "Không thể cập nhật thứ tự của lịch",
     "Import calendars" : "Nhập lịch",
     "Please select a calendar to import into …" : "Vui lòng chọn một lịch để nhập vào  …",
@@ -117,6 +116,11 @@ OC.L10N.register(
     "Settings & import" : "Thiết lập & Nhập vào",
     "CalDAV link copied to clipboard." : "Liên kết CalDAV đã được sao chép vào bảng tạm",
     "CalDAV link could not be copied to clipboard." : "Liên kết CalDAV không thể được sao chép vào bảng tạm.",
+    "Location" : "Vị trí",
+    "Description" : "Mô tả",
+    "Monday" : "Thứ 2",
+    "Save" : "Lưu",
+    "Update" : "Cập nhật",
     "before at" : "trước lúc",
     "Notification" : "Thông báo",
     "Email" : "Thư điện tử",
@@ -135,7 +139,6 @@ OC.L10N.register(
     "_hour_::_hours_" : ["giờ"],
     "_day_::_days_" : ["ngày"],
     "_week_::_weeks_" : ["tuần"],
-    "No reminders yet" : "Chưa có lịch nhắc hẹn nào ",
     "Availability of attendees, resources and rooms" : "Tình trạng tham gia của người dự, nguồn lực và phòng ",
     "Free" : "Rãnh",
     "Busy (tentative)" : "Bận (có khả năng thay đổi)",
@@ -144,6 +147,7 @@ OC.L10N.register(
     "Unknown" : "Không xác định",
     "Create Talk room for this event" : "Tạo một phòng trò chuyện cho sự kiện này",
     "Show busy times" : "Cho thấy các thời gian bận",
+    "No attendees yet" : "Chưa có giờ tham gia",
     "Successfully appended link to talk room to description." : "Liên kết đã được thêm thành công vào mô tả trong phòng trò chuyện ",
     "Error creating Talk room" : "Có lõi xảy ra khi tạo phòng Trò chuyện",
     "Chairperson" : "Chủ tịch",
@@ -152,7 +156,6 @@ OC.L10N.register(
     "Non-participant" : "Người không tham gia",
     "Remove attendee" : "Gỡ bỏ người tham gia",
     "No match found" : "Không có khớp lệnh nào được tìm thấy",
-    "No attendees yet" : "Chưa có giờ tham gia",
     "(organizer)" : "(organizer)",
     "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Để gửi lời mời và tiếp nhận các phản hồi, [linkopen] thêm địa chỉ email riêng của bạn trong phần cài đặt cá nhân[linkclose].",
     "Remove color" : "Gỡ màu",
@@ -162,6 +165,7 @@ OC.L10N.register(
     "from {startDate} at {startTime}" : "từ {startDate} vào lúc {startTime}",
     "to {endDate}" : "đến  {endDate}",
     "to {endDate} at {endTime}" : "đến {endDate} vào lúc {endTime}",
+    "Repeat" : "Lặp lại",
     "End repeat" : "Kết thúc lập lại",
     "Select to end repeat" : "Chọn thời gian kết thúc lặp lại",
     "never" : "không thay đổi",
@@ -175,25 +179,19 @@ OC.L10N.register(
     "second to last" : "kế cuối",
     "last" : "cuối cùng",
     "Changes to the recurrence-rule will only apply to this and all future occurrences." : "các thay đổi đến luật lệ định kỳ này sẽ chỉ áp dụng cho định kỳ này và các định kỳ tương lai của nó ",
-    "Repeat" : "Lặp lại",
     "Repeat every" : "Lặp lại mỗi",
     "By day of the month" : "Vào ngày của tháng",
     "On the" : "Trên",
     "_month_::_months_" : ["tháng"],
     "_year_::_years_" : ["năm"],
-    "Monday" : "Thứ 2",
     "weekday" : "ngày làm việc",
     "weekend day" : "ngày cuối tuần",
-    "Summary" : "Tóm tắt",
     "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Định nghĩa về định kỳ của sự kiện này không hoàn toàn được hỗ trợ bởi vWorkspace. Nếu bạn sửa các lựa chọn định kỳ này, một vài định kỳ có thể sẽ bị mất ",
     "More" : "Thêm",
-    "Save" : "Lưu",
-    "Update" : "Cập nhật",
     "Update this occurrence" : "Cập nhập định kỳ này",
     "Update this and all future" : "Cập nhập định kỳ này và cho toàn bộ tương lai",
     "Public calendar does not exist" : "Lịch công khai không tồn tại",
     "Maybe the share was deleted or has expired?" : "Có lẽ chia sẽ đã bị xóa hoặc hết hạn ? ",
-    "Please select a timezone:" : "Vui lòng chọn múi giờ:",
     "Pick a time" : "Chọn thời gian",
     "Pick a date" : "Chọn ngày",
     "from {formattedDate}" : "từ {formattedDate}",
@@ -205,10 +203,8 @@ OC.L10N.register(
     "{formattedDate} at {formattedTime}" : "{formattedDate} vào lúc {formattedTime}",
     "Please enter a valid date" : "Vui lòng điền vào 1 ngày khả dụng",
     "Please enter a valid date and time" : "Vui lòng điền vào 1 ngày và thời gian khả dụng",
-    "Type to search timezone" : "Nhập để tìm kiếm múi giờ",
+    "Global" : "Chung",
     "Personal" : "Cá nhân",
-    "The automatic timezone detection determined your timezone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your timezone manually in the calendar settings." : "Tự động phát hiện múi giờ xác định múi giờ của bạn trên hệ thống UTC. \nĐây gần như là một trong những kết quả của các phương thức bảo mật của trình duyệt của bạn.\nVui lòng đặt múi giờ của bạn một cách thủ công trong các thiết lập của Lịch. ",
-    "Your configured timezone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your timezone in the settings and report this issue." : "Múi giờ được cấu hình của bạn ({timezoneId}) không được tìm thấy. Đang trở về lại hệ thống UTC.\nVui lòng thay đổi múi giờ của bạn trong Thiết lập và báo cáo vấn đề này. ",
     "No more events today" : "Không có thêm sự kiện nào hôm nay",
     "No upcoming events" : "Không có sự kiện sắp diễn ra ",
     "Create a new event" : "Tạo một sự kiện mới",
@@ -221,7 +217,6 @@ OC.L10N.register(
     "Delete this and all future" : "Xóa địnhy kỳ này và tất cả tương lai của nó",
     "Details" : "Chi tiết",
     "Attendees" : "Người tham gia",
-    "Reminders" : "Nhắc nhở",
     "Close" : "Đóng",
     "Show more details" : "Cho thấy thêm chi tiết",
     "Subscribe to {name}" : "Dõi theo {name}",
@@ -269,6 +264,7 @@ OC.L10N.register(
     "in {monthNames} on the {ordinalNumber} {byDaySet}" : "trong {monthNames} trên {ordinalNumber} {byDaySet}",
     "until {untilDate}" : "cho đến {untilDate}",
     "_%n time_::_%n times_" : ["%n lần"],
+    "Untitled event" : "Sự kiện không tiêu đề",
     "Untitled task" : "Nhiệm vụ không tiêu đề",
     "Please ask your administrator to enable the Tasks App." : "Vui lòng hỏi quản trị viên của bạn để bật ứng dụng Nhiệm Vụ",
     "%n more" : "thêm %n",
@@ -283,9 +279,7 @@ OC.L10N.register(
     "When shared show only busy" : "Khi được chia sẻ thì chỉ cho thấy đang bận",
     "When shared hide this event" : "Khi được chia sẻ thì ẩn sự kiện này đi",
     "The visibility of this event in shared calendars." : "Khả năng nhìn thấy của sự kiện này trong các lịch được chia sẻ",
-    "Location" : "Vị trí",
     "Add a location" : "Thêm vào một địa điểm",
-    "Description" : "Mô tả",
     "Add a description" : "Thêm vào một mô tả",
     "Status" : "Trạng thái",
     "Confirmed" : "Đã xác nhận",
@@ -387,7 +381,6 @@ OC.L10N.register(
     "Wine tasting" : "Thử rựu",
     "Golf" : "Đánh gôn",
     "Dinner" : "Dùng bữa tối",
-    "Lunch" : "Ăn trưa",
-    "Global" : "Chung"
+    "Lunch" : "Ăn trưa"
 },
 "nplurals=1; plural=0;");
